/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package BLL;

import Entity.*;
import DAL.*;

/**
 *处理用户操作相关的业务逻辑层
 * @author Icho
 */
public class UserBLL {

    private UserDAL _pvtUserDAL = new UserDAL();

    /**
     * 用户登录操作
     * @param prmUser 登录的用户对象
     * @return 登录成功的用户对象
     */
    public TEST_User Login(TEST_User prmUser) {
        try {
            if (!CheckPassword(prmUser)) {
                return null;
            }
            return _pvtUserDAL.SelectUserByUserName(prmUser);
        } catch (Exception ex) {
            //处理异常，表示登录失败
            return null;
        } 
    }

    /**
     * 用户退出(注销)操作
     * @param prmUser 要退出的用户对象
     */
    public void Logout(TEST_User prmUser) {
        try {
            //为日志记录提供接口
        } catch (Exception ex) {
        }
    }

    /**
     * 创建一个新的用户
     * @param prmUser 新的用户对象
     * @return 创建成功的用户对象
     */
    public TEST_User CreateUser(TEST_User prmUser) {
        try {
            if (CheckExistedUser(prmUser)) {
                return null;
            }
            return _pvtUserDAL.InsertNewUser(prmUser);
        } catch (Exception ex) {
            //处理异常，表示登录失败
            return null;
        } 
    }

    /**
     * 修改用户密码
     * @param prmUser 需要修改密码的用户对象
     * @param prmPassword 新的密码
     * @return 密码修改成功后的用户对象或空
     */
    public TEST_User ModifyPassword(TEST_User prmUser, String prmPassword) {
        try {
            if (!CheckExistedUser(prmUser)) {
                return null;
            }
            return _pvtUserDAL.UpdateUserPassword(prmUser, prmPassword);
        } catch (Exception ex) {
            //处理异常，表示登录失败
            return null;
        } 
    }

    /**
     * 修改用户信息
     * @param prmUser 需要修改信息的用户对象
     * @param prmNewPersonalInfo 新的用户信息
     * @return 修改过信息后的新用户
     */
    public TEST_User ModifyUserInfo(TEST_User prmUser, String prmNewPersonalInfo) {
        try {
            if (!CheckExistedUser(prmUser)) {
                return null;
            }
            return _pvtUserDAL.UpdateUserPersonalInfo(prmUser, prmNewPersonalInfo);
        } catch (Exception ex) {
            //处理异常，表示登录失败
            return null;
        }

    }

    /**
     * 检查给定用户对象的密码
     * @param prmUser 要检查的用户对象
     * @return 密码是否正确
     */
    public boolean CheckPassword(TEST_User prmUser) {
        try {
            if (!CheckExistedUser(prmUser)) {
                return false;
            }
            TEST_User tmpUser = _pvtUserDAL.SelectUserByUserName(prmUser);
            if (tmpUser.getPassword().equals(prmUser.getPassword())) {
                return true;
            }
            return false;
        } catch (Exception ex) {
            //处理异常，表示登录失败
            return false;
        }
    }

    /**
     * 检查指定用户是否存在
     * @param prmUser 用户对象
     * @return 用户是否存在
     */
    public boolean CheckExistedUser(TEST_User prmUser) {
        try {
            TEST_User tmpUser = _pvtUserDAL.SelectUserByUserName(prmUser);
            if (tmpUser == null) {
                return false;
            }
            return true;
        } catch (Exception ex) {
            //处理异常，表示登录失败
            return false;
        }
    }
}
