/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package DAL;

import Entity.TEST_Log;
import Entity.TEST_User;
import Entity.TEST_LogType;

import java.sql.*;
import java.util.*;
import java.text.DateFormat;

/**
 *处理日志相关操作的数据访问层
 * @author Icho
 */
public class LogDAL {

    private Connection _pvtConnection;
    private Statement _pvtStatement;
    /// <summary>
    /// 插入新日志
    /// </summary>

    /**
     * 插入一条新的日志并返回该日志对象
     * @param prmLog 日志对象
     * @return 成功插入的新日志对象
     * @throws Exception
     */
    public TEST_Log InsertLog(TEST_Log prmLog) throws Exception {
        //数据操作，插入一条新的日志，成功后返回该日志对象，否则抛出异常
        try {
            OpenDB();
            java.util.Date now = prmLog.getCreateTime();
            DateFormat day = DateFormat.getDateTimeInstance();
            String tmpLogTime = day.format(now);
            String tmpUser = prmLog.getUser().getUserName();
            String tmpLogType = prmLog.getLogType().toString();
            String tmpLogObject = "";
            if (prmLog.getLogObject() != null) {
                tmpLogObject = prmLog.getLogObject().toString();
            }
            String tmpInsertStr = "INSERT INTO LogTable(Username,CreateTime,LogType,LogObjectID)"
                    + "VALUES('" + tmpUser + "','" + tmpLogTime + "','" + tmpLogType + "','" + tmpLogObject + "');";
            _pvtStatement.executeUpdate(tmpInsertStr);
            CloseDB();
            return prmLog;
        } catch (Exception ex) {
            CloseDB();
            throw ex;
        }
    }
    /// <summary>
    /// 获取日志
    /// </summary>

    /**
     * 根据产生日志用户对象获取日志的数据访问操作
     * @param prmUser 产生该日志的用户
     * @param prmCount 需要获取记录的最大条数
     * @return 指定数量的日志记录集合
     * @throws Exception
     */
    public List<TEST_Log> SelectLogsByUser(TEST_User prmUser, int prmCount) throws Exception {
        List tmpList = new LinkedList<TEST_Log>();
        //数据操作，查询获取给定最大数量的所有有关该用户的日志，返回日志链表，错误抛出异常
        try {
            OpenDB();
            String tmpSelectStr = "SELECT TOP " + prmCount + " * FROM LogTable WHERE Username='" + prmUser.getUserName() + "';";
            ResultSet tmpRS = _pvtStatement.executeQuery(tmpSelectStr);
            while (tmpRS.next()) {
                java.util.Date tmpTime = tmpRS.getTime("CreateTime");
                String tmpLogTypeStr = tmpRS.getString("LogType");
                TEST_LogType tmpLogType = TEST_LogType.valueOf(tmpLogTypeStr);
                Object tmpObject = tmpRS.getObject("LogObjectID");
                TEST_Log tmpLog = new TEST_Log(prmUser, tmpTime, tmpLogType, tmpObject);
                tmpList.add(tmpLog);
            }
            tmpRS.close();
            CloseDB();
            return tmpList;
        } catch (Exception ex) {
            CloseDB();
            throw ex;
        }
    }

    /**
     * 根据日志记录产生时间获取日志的数据访问操作
     * @param prmCreateTime 日志记录产生时间
     * @param prmCount 需要获取记录的最大条数
     * @return 指定数量的日志记录集合
     * @throws Exception
     */
    public List<TEST_Log> SelectLogsByCreateTime(java.util.Date prmCreateTime, int prmCount) throws Exception {
        List tmpList = new LinkedList<TEST_Log>();
        String tmpDate;
        java.util.Date now = prmCreateTime;
        DateFormat day = DateFormat.getDateTimeInstance();
        tmpDate = day.format(now);
        //数据操作，查询获取给定最大数量的所有该时间产生的日志，返回日志链表，错误抛出异常
        try {
            OpenDB();
            String tmpSelectStr = "SELECT TOP " + prmCount + " * FROM LogTable WHERE CreateTime=#" + tmpDate + "#";
            ResultSet tmpRS = _pvtStatement.executeQuery(tmpSelectStr);
            while (tmpRS.next()) {
                TEST_User tmpUser = new TEST_User(tmpRS.getString("Username"), null, null);
                TEST_LogType tmpLogType = TEST_LogType.valueOf(tmpRS.getString("LogType"));
                Object tmpObject = tmpRS.getObject("LogObjectID");
                TEST_Log tmpLog = new TEST_Log(tmpUser, prmCreateTime, tmpLogType, tmpObject);
                tmpList.add(tmpLog);
            }
            CloseDB();
            return tmpList;
        } catch (Exception ex) {
            CloseDB();
            throw ex;
        }
        
    }

    /**
     * 根据日志记录类型获取日志的数据访问操作
     * @param prmLogType 日志类型
     * @param prmCount 需要获取记录的最大条数
     * @return 指定数量的日志记录集合
     * @throws Exception
     */
    public List<TEST_Log> SelectLogsByLogType(TEST_LogType prmLogType, int prmCount) throws Exception {
        List tmpList = new LinkedList<TEST_Log>();
        //数据操作，查询获取给定最大数量的所有该日志类型的日志，返回日志链表，错误抛出异常
        try {
            OpenDB();
            String tmpSelectStr = "SELECT TOP " + prmCount + " * FROM LogTable WHERE LogType='" + prmLogType.toString() + "';";
            ResultSet tmpRS = _pvtStatement.executeQuery(tmpSelectStr);
            while (tmpRS.next()) {
                java.util.Date tmpTime = tmpRS.getTime("CreateTime");
                Object tmpObject = tmpRS.getObject("LogObjectID");
                TEST_User tmpUser = new TEST_User(tmpRS.getString("Username"), null, null);
                TEST_Log tmpLog = new TEST_Log(tmpUser, tmpTime, prmLogType, tmpObject);
                tmpList.add(tmpLog);
            }
            tmpRS.close();
            CloseDB();
            return tmpList;
        } catch (Exception ex) {
            CloseDB();
            throw ex;
        }
    }

    /**
     * 根据日志记录对象获取日志的数据访问操作
     * @param prmLogObject 日志记录对象
     * @param prmCount 需要获取记录的最大条数
     * @return 指定数量的日志记录集合
     * @throws Exception
     */
    public List<TEST_Log> SelectLogsByLogObject(Object prmLogObject, int prmCount) throws Exception {
        List tmpList = new LinkedList<TEST_Log>();
        //数据操作，查询获取给定最大数量的所有有关该对象的日志，返回日志链表，错误抛出异常
        try {
            OpenDB();
            String tmpSelectStr = "SELECT TOP " + prmCount + " * FROM LogTable WHERE LogObjectID='" + prmLogObject.toString() + "';";
            ResultSet tmpRS = _pvtStatement.executeQuery(tmpSelectStr);
            while (tmpRS.next()) {
                java.util.Date tmpTime = tmpRS.getTime("CreateTime");
                String tmpLogTypeStr = tmpRS.getString("LogType");
                TEST_LogType tmpLogType = TEST_LogType.valueOf(tmpLogTypeStr);
                TEST_User tmpUser = new TEST_User(tmpRS.getString("Username"), null, null);
                TEST_Log tmpLog = new TEST_Log(tmpUser, tmpTime, tmpLogType, prmLogObject);
                tmpList.add(tmpLog);
            }
            tmpRS.close();
            CloseDB();
            return tmpList;
        } catch (Exception ex) {
            CloseDB();
            throw ex;
        }
    }

    /**
     * 打开数据库连接
     * @throws Exception
     */
    public void OpenDB() throws Exception {

        try {
            Class.forName("sun.jdbc.odbc.JdbcOdbcDriver");
            /**
             * 直接连接access文件。
             */
            String dburl = "jdbc:odbc:TEST_DB;";//需要设置数据源
            String user = "admin";
            String psw = "123456";
            Properties prop = new Properties();
            prop.put("charSet", "gb2312");
            prop.put("user", user);
            prop.put("password", psw);
            _pvtConnection = DriverManager.getConnection(dburl, prop);
            _pvtStatement = _pvtConnection.createStatement();
        } catch (Exception e) {
            System.out.println(e.toString() + "连接数据库失败！");
            throw new SQLException("连接数据库失败！" + e);
        }
    }

    /**
     * 关闭数据库连接
     */
    public void CloseDB() {
        try {
            if (_pvtStatement != null) {
                _pvtStatement.close();
                _pvtStatement = null;
            }
            if (_pvtConnection != null) {
                _pvtConnection.close();
                _pvtConnection = null;
            }
        } catch (Exception e) {
        }

    }
}
